@@ -12,6 +12,7 @@ import numpy as np
 
 def cappuccino(text,
                time,
+               date_format,
                plot,
                ngram,
                time_freq,
@@ -24,6 +25,7 @@ def cappuccino(text,
 
     result = arabica_freq(text=text,
                           time=time,
+                          date_format = date_format,
                           time_freq=time_freq,
                           max_words=max_words,
                           stopwords=stopwords,
@@ -72,13 +74,21 @@ def cappuccino(text,
             reshaped_unigram = reshaped_unigram.dropna()
             reshaped_unigram['frequency'] = reshaped_unigram['frequency'].astype(int)
             reshaped_unigram = reshaped_unigram.merge(period_re, left_index = True, right_index = True)
-            reshaped_unigram_max = reshaped_unigram.groupby(['unigram'], sort=False)['frequency'].max()
-            reshaped_unigram_max = reshaped_unigram_max.reset_index()
-            reshaped_unigram = reshaped_unigram.merge(reshaped_unigram_max, on = ['unigram','frequency'], how = 'left', indicator=True)
-            reshaped_unigram['label'] = np.where(reshaped_unigram['_merge']=='both', reshaped_unigram['unigram'], '')
-            reshaped_unigram = reshaped_unigram[['unigram', 'frequency', 'period','label']]
 
             if plot == 'heatmap':
+                reshaped_unigram = reshaped['unigram']
+                reshaped_unigram.reset_index(drop=True, inplace=True)
+                reshaped_unigram = reshaped_unigram.str.split(pat=": ", expand=True)
+                reshaped_unigram = reshaped_unigram.rename(columns={0: 'unigram', 1: 'frequency'})
+                reshaped_unigram = reshaped_unigram.dropna()
+                reshaped_unigram['frequency'] = reshaped_unigram['frequency'].astype(int)
+                reshaped_unigram = reshaped_unigram.merge(period_re, left_index = True, right_index = True)
+                reshaped_unigram_max = reshaped_unigram.groupby(['unigram'], sort=False)['frequency'].max()
+                reshaped_unigram_max = reshaped_unigram_max.reset_index()
+                reshaped_unigram = reshaped_unigram.merge(reshaped_unigram_max, on = ['unigram','frequency'], how = 'left', indicator=True)
+                reshaped_unigram['label'] = np.where(reshaped_unigram['_merge']=='both', reshaped_unigram['unigram'], '')
+                reshaped_unigram = reshaped_unigram[['unigram', 'frequency', 'period','label']]
+
                 fig = (ggplot(reshaped_unigram, aes('period', 'unigram', fill='frequency'))
                        + geom_tile(aes(width=.95, height=.95))
                        + geom_text(aes(label='frequency'), size=10)
@@ -89,7 +99,7 @@ def cappuccino(text,
                        + theme(axis_title_x=element_text(colour = "black"),
                                axis_title_y=element_text(colour="black"),
                                axis_text_x=element_text(colour = "black", rotation=45, hjust=1),
-                               figure_size=(10, 6),
+                               figure_size=(10, 5),
                                panel_grid_major = element_blank(),
                                panel_background = element_rect(colour = "white", fill = "white"),
                                plot_background = element_rect(colour = 'white',fill = "white"))
@@ -101,10 +111,21 @@ def cappuccino(text,
 
 
             elif plot == 'line':
-                fig = (ggplot(reshaped_unigram)
+                reshaped_unigram_wide = pd.pivot(reshaped_unigram, index = 'unigram', columns = 'period', values = 'frequency')
+                reshaped_unigram_wide = reshaped_unigram_wide.fillna(0)
+                year_list=list(reshaped_unigram_wide.columns)
+                reshaped_unigram_wide = pd.melt(reshaped_unigram_wide, value_vars=year_list,value_name='frequency', ignore_index=False)
+                reshaped_unigram_wide = reshaped_unigram_wide.reset_index()
+                reshaped_unigram_max = reshaped_unigram_wide.groupby(['unigram'], sort=False)['frequency'].max()
+                reshaped_unigram_max = reshaped_unigram_max.reset_index()
+                reshaped_unigram_wide = reshaped_unigram_wide.merge(reshaped_unigram_max, on = ['unigram','frequency'], how = 'left', indicator=True)
+                reshaped_unigram_wide['label'] = np.where(reshaped_unigram_wide['_merge']=='both', reshaped_unigram_wide['unigram'], '')
+                reshaped_unigram_wide = reshaped_unigram_wide[['unigram', 'frequency', 'period','label']]
+
+                fig = (ggplot(reshaped_unigram_wide)
                        + geom_point(aes(x = 'period', y = 'frequency',color = 'unigram'))
                        + geom_line(aes(x = 'period', y = 'frequency', color = 'unigram',group='unigram'))
-                       + geom_label(aes(x = 'period', y = 'frequency', label = 'label',size = 0.2), nudge_y=0.3)
+                       + geom_label(aes(x = 'period', y = 'frequency', label = 'label',size = 1), nudge_y=2)
                        + scale_size_continuous(guide = None)
                        + guides(color=guide_legend(nrow=40))
                        + theme_minimal()
@@ -116,7 +137,7 @@ def cappuccino(text,
                                legend_title = element_text(size=10),
                                legend_key_height = 0.5,
                                legend_key_width = 0.5,
-                               figure_size=(10, 6),
+                               figure_size=(10, 5),
                                panel_grid_major = element_blank(),
                                panel_background = element_rect(colour = "white", fill = "white"),
                                plot_background = element_rect(colour = 'white',fill = "white"))
@@ -145,15 +166,21 @@ def cappuccino(text,
             reshaped_unigram = reshaped_unigram.dropna()
             reshaped_unigram['frequency'] = reshaped_unigram['frequency'].astype(int)
             reshaped_unigram = reshaped_unigram.merge(period_re, left_index = True, right_index = True)
-            reshaped_unigram_max = reshaped_unigram.groupby(['unigram'], sort=False)['frequency'].max()
-            reshaped_unigram_max = reshaped_unigram_max.reset_index()
-            reshaped_unigram = reshaped_unigram.merge(reshaped_unigram_max, on = ['unigram','frequency'], how = 'left', indicator=True)
-            reshaped_unigram['label'] = np.where(reshaped_unigram['_merge']=='both', reshaped_unigram['unigram'], '')
-            reshaped_unigram = reshaped_unigram[['unigram', 'frequency', 'period','label']]
-
-
 
             if plot == 'heatmap':
+                reshaped_unigram = reshaped['unigram']
+                reshaped_unigram.reset_index(drop=True, inplace=True)
+                reshaped_unigram = reshaped_unigram.str.split(pat=": ", expand=True)
+                reshaped_unigram = reshaped_unigram.rename(columns={0: 'unigram', 1: 'frequency'})
+                reshaped_unigram = reshaped_unigram.dropna()
+                reshaped_unigram['frequency'] = reshaped_unigram['frequency'].astype(int)
+                reshaped_unigram = reshaped_unigram.merge(period_re, left_index = True, right_index = True)
+                reshaped_unigram_max = reshaped_unigram.groupby(['unigram'], sort=False)['frequency'].max()
+                reshaped_unigram_max = reshaped_unigram_max.reset_index()
+                reshaped_unigram = reshaped_unigram.merge(reshaped_unigram_max, on = ['unigram','frequency'], how = 'left', indicator=True)
+                reshaped_unigram['label'] = np.where(reshaped_unigram['_merge']=='both', reshaped_unigram['unigram'], '')
+                reshaped_unigram = reshaped_unigram[['unigram', 'frequency', 'period','label']]
+
                 fig = (ggplot(reshaped_unigram, aes('period', 'unigram', fill='frequency'))
                        + geom_tile(aes(width=.95, height=.95))
                        + geom_text(aes(label='frequency'), size=10)
@@ -174,8 +201,18 @@ def cappuccino(text,
                 picture = plt.show()
 
             elif plot == 'line':
+                reshaped_unigram_wide = pd.pivot(reshaped_unigram, index = 'unigram', columns = 'period', values = 'frequency')
+                reshaped_unigram_wide = reshaped_unigram_wide.fillna(0)
+                year_list=list(reshaped_unigram_wide.columns)
+                reshaped_unigram_wide = pd.melt(reshaped_unigram_wide, value_vars=year_list,value_name='frequency', ignore_index=False)
+                reshaped_unigram_wide = reshaped_unigram_wide.reset_index()
+                reshaped_unigram_max = reshaped_unigram_wide.groupby(['unigram'], sort=False)['frequency'].max()
+                reshaped_unigram_max = reshaped_unigram_max.reset_index()
+                reshaped_unigram_wide = reshaped_unigram_wide.merge(reshaped_unigram_max, on = ['unigram','frequency'], how = 'left', indicator=True)
+                reshaped_unigram_wide['label'] = np.where(reshaped_unigram_wide['_merge']=='both', reshaped_unigram_wide['unigram'], '')
+                reshaped_unigram_wide = reshaped_unigram_wide[['unigram', 'frequency', 'period','label']]
 
-                fig = (ggplot(reshaped_unigram)
+                fig = (ggplot(reshaped_unigram_wide)
                        + geom_point(aes(x = 'period', y = 'frequency',color = 'unigram'))
                        + geom_line(aes(x = 'period', y = 'frequency', color = 'unigram',group='unigram'))
                        + geom_label(aes(x = 'period', y = 'frequency', label = 'label',size = 0.2), nudge_y=0.3)
@@ -190,7 +227,7 @@ def cappuccino(text,
                                legend_title = element_text(size=10),
                                legend_key_height = 0.5,
                                legend_key_width = 0.5,
-                               figure_size=(10, 6),
+                               figure_size=(10, 5),
                                panel_grid_major = element_blank(),
                                panel_background = element_rect(colour = "white", fill = "white"),
                                plot_background = element_rect(colour = 'white',fill = "white"))
@@ -245,13 +282,14 @@ def cappuccino(text,
             reshaped_unigram = reshaped_unigram.dropna()
             reshaped_unigram['frequency'] = reshaped_unigram['frequency'].astype(int)
             reshaped_unigram = reshaped_unigram.merge(period_re, left_index = True, right_index = True)
-            reshaped_unigram_max = reshaped_unigram.groupby(['bigram'], sort=False)['frequency'].max()
-            reshaped_unigram_max = reshaped_unigram_max.reset_index()
-            reshaped_unigram = reshaped_unigram.merge(reshaped_unigram_max, on = ['bigram','frequency'], how = 'left', indicator=True)
-            reshaped_unigram['label'] = np.where(reshaped_unigram['_merge']=='both', reshaped_unigram['bigram'], '')
-            reshaped_unigram = reshaped_unigram[['bigram', 'frequency', 'period','label']]
 
             if plot == 'heatmap':
+                reshaped_unigram_max = reshaped_unigram.groupby(['bigram'], sort=False)['frequency'].max()
+                reshaped_unigram_max = reshaped_unigram_max.reset_index()
+                reshaped_unigram = reshaped_unigram.merge(reshaped_unigram_max, on = ['bigram','frequency'], how = 'left', indicator=True)
+                reshaped_unigram['label'] = np.where(reshaped_unigram['_merge']=='both', reshaped_unigram['bigram'], '')
+                reshaped_unigram = reshaped_unigram[['bigram', 'frequency', 'period','label']]
+
                 fig = (ggplot(reshaped_unigram, aes('period', 'bigram', fill='frequency'))
                        + geom_tile(aes(width=.95, height=.95))
                        + geom_text(aes(label='frequency'), size=10)
@@ -274,7 +312,19 @@ def cappuccino(text,
 
 
             elif plot == 'line':
-                fig = (ggplot(reshaped_unigram)
+                reshaped_unigram_wide = pd.pivot(reshaped_unigram, index = 'bigram', columns = 'period', values = 'frequency')
+                reshaped_unigram_wide = reshaped_unigram_wide.fillna(0)
+                year_list=list(reshaped_unigram_wide.columns)
+                reshaped_unigram_wide = pd.melt(reshaped_unigram_wide, value_vars=year_list,value_name='frequency', ignore_index=False)
+                reshaped_unigram_wide = reshaped_unigram_wide.reset_index()
+                reshaped_unigram_max = reshaped_unigram_wide.groupby(['bigram'], sort=False)['frequency'].max()
+                reshaped_unigram_max = reshaped_unigram_max.reset_index()
+                reshaped_unigram_wide = reshaped_unigram_wide.merge(reshaped_unigram_max, on = ['bigram','frequency'], how = 'left', indicator=True)
+                reshaped_unigram_wide['label'] = np.where(reshaped_unigram_wide['_merge']=='both', reshaped_unigram_wide['bigram'], '')
+                reshaped_unigram_wide = reshaped_unigram_wide[['bigram', 'frequency', 'period','label']]
+
+
+                fig = (ggplot(reshaped_unigram_wide)
                        + geom_point(aes(x = 'period', y = 'frequency',color = 'bigram'))
                        + geom_line(aes(x = 'period', y = 'frequency', color = 'bigram',group='bigram'))
                        + geom_label(aes(x = 'period', y = 'frequency', label = 'label',size = 0.2), nudge_y=0.3)
@@ -289,7 +339,7 @@ def cappuccino(text,
                                legend_title = element_text(size=10),
                                legend_key_height = 0.5,
                                legend_key_width = 0.5,
-                               figure_size=(10, 6),
+                               figure_size=(10, 5),
                                panel_grid_major = element_blank(),
                                panel_background = element_rect(colour = "white", fill = "white"),
                                plot_background = element_rect(colour = 'white',fill = "white"))
@@ -322,13 +372,14 @@ def cappuccino(text,
             reshaped_unigram = reshaped_unigram.dropna()
             reshaped_unigram['frequency'] = reshaped_unigram['frequency'].astype(int)
             reshaped_unigram = reshaped_unigram.merge(period_re, left_index = True, right_index = True)
-            reshaped_unigram_max = reshaped_unigram.groupby(['bigram'], sort=False)['frequency'].max()
-            reshaped_unigram_max = reshaped_unigram_max.reset_index()
-            reshaped_unigram = reshaped_unigram.merge(reshaped_unigram_max, on = ['bigram','frequency'], how = 'left', indicator=True)
-            reshaped_unigram['label'] = np.where(reshaped_unigram['_merge']=='both', reshaped_unigram['bigram'], '')
-            reshaped_unigram = reshaped_unigram[['bigram', 'frequency', 'period','label']]
 
             if plot == 'heatmap':
+                reshaped_unigram_max = reshaped_unigram.groupby(['bigram'], sort=False)['frequency'].max()
+                reshaped_unigram_max = reshaped_unigram_max.reset_index()
+                reshaped_unigram = reshaped_unigram.merge(reshaped_unigram_max, on = ['bigram','frequency'], how = 'left', indicator=True)
+                reshaped_unigram['label'] = np.where(reshaped_unigram['_merge']=='both', reshaped_unigram['bigram'], '')
+                reshaped_unigram = reshaped_unigram[['bigram', 'frequency', 'period','label']]
+
                 fig = (ggplot(reshaped_unigram, aes('period', 'bigram', fill='frequency'))
                        + geom_tile(aes(width=.95, height=.95))
                        + geom_text(aes(label='frequency'), size=10)
@@ -351,7 +402,19 @@ def cappuccino(text,
 
 
             elif plot == 'line':
-                fig = (ggplot(reshaped_unigram)
+                reshaped_unigram_wide = pd.pivot(reshaped_unigram, index = 'bigram', columns = 'period', values = 'frequency')
+                reshaped_unigram_wide = reshaped_unigram_wide.fillna(0)
+                year_list=list(reshaped_unigram_wide.columns)
+                reshaped_unigram_wide = pd.melt(reshaped_unigram_wide, value_vars=year_list,value_name='frequency', ignore_index=False)
+                reshaped_unigram_wide = reshaped_unigram_wide.reset_index()
+                reshaped_unigram_max = reshaped_unigram_wide.groupby(['bigram'], sort=False)['frequency'].max()
+                reshaped_unigram_max = reshaped_unigram_max.reset_index()
+                reshaped_unigram_wide = reshaped_unigram_wide.merge(reshaped_unigram_max, on = ['bigram','frequency'], how = 'left', indicator=True)
+                reshaped_unigram_wide['label'] = np.where(reshaped_unigram_wide['_merge']=='both', reshaped_unigram_wide['bigram'], '')
+                reshaped_unigram_wide = reshaped_unigram_wide[['bigram', 'frequency', 'period','label']]
+
+
+                fig = (ggplot(reshaped_unigram_wide)
                        + geom_point(aes(x = 'period', y = 'frequency',color = 'bigram'))
                        + geom_line(aes(x = 'period', y = 'frequency', color = 'bigram',group='bigram'))
                        + geom_label(aes(x = 'period', y = 'frequency', label = 'label',size = 0.2), nudge_y=0.3)
@@ -366,7 +429,7 @@ def cappuccino(text,
                                legend_title = element_text(size=10),
                                legend_key_height = 0.5,
                                legend_key_width = 0.5,
-                               figure_size=(10, 6),
+                               figure_size=(10, 5),
                                panel_grid_major = element_blank(),
                                panel_background = element_rect(colour = "white", fill = "white"),
                                plot_background = element_rect(colour = 'white',fill = "white"))
